function cfg = config_subjects(cfg)

% Sets analysis specific variables

%% Set experimental name (= experiment folder) and file prefix

cfg.name = 'decoding_example';
cfg.prefix = 'decoding';
cfg.prefix_localizer = 'localizer';
cfg.suffix = 'img'; % img or nii (tested with img)

%% Set and add paths

% first, set this to the folder that contains \DICOM
if ispc, data_dir = 'D:\TDT\decoding_example'; % if you use windows
else	 data_dir = '/home/TDT/decoding_example'; % if you use linux
end

cfg.dirs.data_dir = data_dir;

%% Set scanner-specific and basic analysis variables

cfg.TR = 2;
cfg.n_slices = 39;
cfg.voxdims = [2 2 3];
cfg.sliceorder = 'descending'; % can be ascending, descending, interleaved, or interleaved descending
cfg.reference_slice = 20;
cfg.FWHM = 6; % mm

%% Set subjects to use for analysis
excluded_subjects = [];
    % e.g. excluded because of excessive motion (don't need to continue
    % processing after realignment, plus not included in DARTEL!)
  
% try % example where changing the cfg might me important if you are currently running a specific analysis (this can be added manually for this analysis)
%     if cfg.do.secondlevel.decoding.decision1bin_stimulus_up.t
%    
%         excluded_subjects = [4 8 9 16];
%    
%     end
% end
  

    
excluded_runs = {};


%% Set import specific variables

cfg.n_dummy = 5; % number of dummy scans to remove in beginning of each run
cfg.n_scans_experiment = 200; % to remove trailing scans
cfg.n_scans_localizer = 248; % to remove trailing scans

%% Set Subject Variables

% Subject 1
cfg.sub(1).id = 'PARTICIPANT1'; % folder name of dicom folder
cfg.sub(1).pid = 'XXXXX'; % subject id anonymized
cfg.sub(1).age = 99;
cfg.sub(1).gender = 1; % 1 is female, 0 is male
cfg.sub(1).handedness = 1; % 1 is right, -1 is left
cfg.sub(1).import.experiment = [4 5 6 7 8 9 10 11];
cfg.sub(1).import.color_localizer = 12;
cfg.sub(1).import.motion_localizer = 13;
cfg.sub(1).import.anatomy = 14;
cfg.sub(1).preproc.corrupted_slices = [];
cfg.sub(1).behav_resname = '^res_sampleexp_sub01.*\.mat$'; % regexp for results files
cfg.sub(1).roi.mt_left.position = [75 28 15];
cfg.sub(1).roi.mt_right.position = [35 30 14];
cfg.sub(1).roi.v4_left.position = [70 30 9];
cfg.sub(1).roi.v4_right.position = [42 27 8];

% Subject 2
cfg.sub(2).id = 'PARTICIPANT2'; % folder name of dicom folder
cfg.sub(2).pid = 'YYYYY'; % subject id anonymized
cfg.sub(2).age = 99;
cfg.sub(2).gender = 0; % 1 is female, 0 is male
cfg.sub(2).handedness = -1; % 1 is right, -1 is left
cfg.sub(2).import.experiment = [2 3 4 5 6 7 8 9];
cfg.sub(2).import.color_localizer = 10;
cfg.sub(2).import.motion_localizer = 11;
cfg.sub(2).import.anatomy = 12;
cfg.sub(2).preproc.corrupted_slices = [];
cfg.sub(2).behav_resname = '^res_sampleexp_sub02.*\.mat$'; % regexp for results files
cfg.sub(2).roi.mt_left.position = [75 30 18];
cfg.sub(2).roi.mt_right.position = [34 29 19];
cfg.sub(2).roi.v4_left.position = [64 36 18];
cfg.sub(2).roi.v4_right.position = [41 28 14];


%% Set other subject variables automatically

% Here, run numbers are generated from imported numbers (e.g. imported run
% 3 would be run 1, because imported run 1 is brain localizer and imported
% run 2 is anatomical)

% Set for all subject to use all experimental runs provided
for i_sub = 1:length(cfg.sub) %cfg.subject_indices
    cfg.sub(i_sub).n_runs = length(cfg.sub(i_sub).import.experiment);
    cfg.sub(i_sub).run_indices = 1:cfg.sub(i_sub).n_runs;
    cfg.sub(i_sub).run_indices_decoding = 1:cfg.sub(i_sub).n_runs;
    if (i_sub <= length(excluded_runs) && ~isempty(excluded_runs{i_sub}))
        cfg.sub(i_sub).run_indices_decoding = setdiff(cfg.sub(i_sub).run_indices_decoding,excluded_runs{i_sub});
    end
end


% Run numbers to use (although we import all runs, we might have one
% corrupted run, so we might not use them all)

% If necessary, set exceptions
% example:
% cfg.sub(7).n_runs = length(cfg.sub(7).import.experiment) -1;
% cfg.sub(7).run_indices = [1:8 10];

% Subjects to be used (some subjects might have to be excluded later)
if ~isfield(cfg,'subject_indices')
    cfg.subject_indices = setdiff(1:length(cfg.sub),excluded_subjects);
end

%% Set paths    
for i = 1:length(cfg.sub)
    cfg.sub(i).dir = fullfile(data_dir,sprintf('sub%02d',i));
end