function res = convert_results

subnum = 1:2; % Subject number (can be range)
n_runs = 8;
expname = 'sampleexp';
cwd = 'D:\UKE';
base_dir = fullfile(cwd,expname); % D:\UKE\sampleexp
results_dir = fullfile(base_dir,'behavioral','results');

clear onsets cues colors directions responsemapping responsemapping_set buttonpress RT accuracy

for i_sub = subnum

    data = [];
    
    substr = sprintf('sub%02d',i_sub);
    
    for i_run = 1:n_runs
        runstr = sprintf('run%02d',i_run);
        str = sprintf('res_%s_%s_%s.mat',expname,substr,runstr);
        load(fullfile(results_dir,substr,str))
        n_trials = length(data.trial);
        
        res{i_sub,i_run}.cfg = data.cfg;
        res{i_sub,i_run}.onsets = getons(data); % onsets are cue onsets
        
        res{i_sub,i_run}.cues = [data.trial.cue];
        res{i_sub,i_run}.colors = [data.trial.stim_color];
        res{i_sub,i_run}.directions = [data.trial.stim_direction];
        res{i_sub,i_run}.responsemapping = [data.trial.responsemapping];
        res{i_sub,i_run}.responsemapping_set = [data.trial.responsemapping_set];
        for i_trial = 1:n_trials
            res{i_sub,i_run}.buttonpress(i_trial) = data.results(i_trial).response.side;
            res{i_sub,i_run}.RT(i_trial) = data.results(i_trial).response.RT / 1000; % convert to seconds
            res{i_sub,i_run}.accuracy(i_trial) = double(data.results(i_trial).response.accuracy);
        end
        
        res{i_sub,i_run}.missed_trials = isnan(res{i_sub,i_run}.RT);
        
    end
end


function onsets = getons(data)

% return trial onsets in seconds

starttime = data.starttime;

try
    onsets = [data.trial.T]-starttime;
catch
    onsets = [data.results.starttime]-starttime;
end

onsets = onsets/1000;