function varargout = getons_attention(cfg,i_sub,save_on,overwrite)

% Model cue (separately), stimulus direction (separately), stimulus color (separately), buttonpresses (separately). 
% Leave out attention

if ~exist('save_on','var')
    save_on = 0;
end

if ~exist('overwrite','var')
    overwrite = 0;
end

onsname = mfilename;
onsname = onsname(8:end);
if isempty(onsname), onsname = 'test'; end

for i_run = cfg.sub(i_sub).run_indices

outputname = sprintf('%s_sub%02d_run%02d.mat',onsname,i_sub,i_run);

output_dir = fullfile(cfg.sub(i_sub).dir,'onsets',onsname);

if exist(fullfile(output_dir,outputname),'file')
    if overwrite
        warning([mfilename ':overwrite'],'Overwriting files in %s',output_dir);
        warning('off',[mfilename ':overwrite'])        
    else
        error('File %s already exists! Set overwrite = 1 or run different analysis.',fullfile(output_dir,outputname));
    end
end

res = convert_results; % get results matrix
res = res{i_sub,i_run}; % also converts to seconds

cue_dur = 1.5;
ISI1 = 1;
stim_dur = 6;
ISI2 = 1;
ITI = 1;

%% This is the only part of code modified for this function

[res,res_missed] = remove_missed(res);


names = {'red attended','green attended','red unattended','green unattended','up attended','down attended','up unattended','down unattended'};
onsets = cell(size(names));
durations = cell(size(names));

% stimulus onset
ind{1} = res.cues == 1 & res.colors == 1;
ind{2} = res.cues == 1 & res.colors == 2;
ind{3} = res.cues == 2 & res.colors == 1;
ind{4} = res.cues == 2 & res.colors == 2;
ind{5} = res.cues == 2 & res.directions == 90;
ind{6} = res.cues == 2 & res.directions == 270;
ind{7} = res.cues == 1 & res.directions == 90;
ind{8} = res.cues == 1 & res.directions == 270;

for i = 1:8
    % cue onset + cue_dur + ISI1 = stimulus onset
    onsets{1,i} = res.onsets(ind{i}) + cue_dur + ISI1;
end

% Separately model missed trials if requested
% Not now

for i = 1:length(durations)
    durations{i} = stim_dur * ones(size(onsets{i}));
end


%% End of modification

varargout{1} = names;
varargout{2} = onsets;
varargout{3} = durations;
if exist('pmod','var')
    varargout{4} = pmod;
end

if save_on
    if ~isdir(output_dir), mkdir(output_dir), end
    if exist('pmod','var')
        save(fullfile(output_dir,outputname),'names','onsets','durations','pmod')
    else
        save(fullfile(output_dir,outputname),'names','onsets','durations')
    end
end

end

warning('on',[mfilename ':overwrite'])