function varargout = getons_buttonpresses(cfg,i_sub,save_on,overwrite)

if ~exist('save_on','var')
    save_on = 0;
end

if ~exist('overwrite','var')
    overwrite = 0;
end

onsname = mfilename;
onsname = onsname(8:end);
if isempty(onsname), onsname = 'test'; end

for i_run = cfg.sub(i_sub).run_indices

outputname = sprintf('%s_sub%02d_run%02d.mat',onsname,i_sub,i_run);

output_dir = fullfile(cfg.sub(i_sub).dir,'onsets',onsname);

if exist(fullfile(output_dir,outputname),'file')
    if overwrite
        warning([mfilename ':overwrite'],'Overwriting files in %s',output_dir);
        warning('off',[mfilename ':overwrite'])        
    else
        error('File %s already exists! Set overwrite = 1 or run different analysis.',fullfile(output_dir,outputname));
    end
end

res = convert_results; % get results matrix
res = res{i_sub,i_run}; % also converts to seconds

cue_dur = 1.5;
ISI1 = 1;
stim_dur = 6;
ISI2 = 1;
ITI = 1;

%% This is the only part of code modified for this function

names = {'button left','button right'};
onsets = cell(size(names));
durations = cell(size(names));

[res,res_missed] = remove_missed(res);

coding = [-1 1]; % button_left = -1; button_right = 1;

for i = 1:2
    ind = res.buttonpress == coding(i);
    % cue onset + cue duration + ISI1 + stimulus duration + ISI2 + response time = onset of button press
    onsets{1,i} = res.onsets(ind) + cue_dur + ISI1 + stim_dur + ISI2 + res.RT(ind);
end


% Separately model missed trials if requested
% Not here, because no button press


% Event modeled as 0 duration
for i = 1:length(durations)
    durations{i} = zeros(size(onsets{i}));
end



%% End of modification

varargout{1} = names;
varargout{2} = onsets;
varargout{3} = durations;
if exist('pmod','var')
    varargout{4} = pmod;
end

if save_on
    if ~isdir(output_dir), mkdir(output_dir), end
    if exist('pmod','var')
        save(fullfile(output_dir,outputname),'names','onsets','durations','pmod')
    else
        save(fullfile(output_dir,outputname),'names','onsets','durations')
    end
end

end

warning('on',[mfilename ':overwrite'])