function varargout = getons_full(cfg,i_sub,save_on,overwrite)

% Model cue (separately), stimulus direction (separately), stimulus color (separately), buttonpresses (separately). 
% Leave out attention

if ~exist('save_on','var')
    save_on = 0;
end

if ~exist('overwrite','var')
    overwrite = 0;
end

onsname = mfilename;
onsname = onsname(8:end);
if isempty(onsname), onsname = 'test'; end

for i_run = cfg.sub(i_sub).run_indices

outputname = sprintf('%s_sub%02d_run%02d.mat',onsname,i_sub,i_run);

output_dir = fullfile(cfg.sub(i_sub).dir,'onsets',onsname);

if exist(fullfile(output_dir,outputname),'file')
    if overwrite
        warning([mfilename ':overwrite'],'Overwriting files in %s',output_dir);
        warning('off',[mfilename ':overwrite'])       
    else
        error('File %s already exists! Set overwrite = 1 or run different analysis.',fullfile(output_dir,outputname));
    end
end

res = convert_results; % get results matrix
res = res{i_sub,i_run}; % also converts to seconds

cue_dur = 1.5;
ISI1 = 1;
stim_dur = 6;
ISI2 = 1;
ITI = 1;

%% This is the only part of code modified for this function

[res,res_missed] = remove_missed(res);


%% Cue
names_cue = {'color','direction'};
onsets_cue = cell(size(names_cue));
durations_cue = cell(size(names_cue));


coding = [1 2]; % color = 1; direction = 2;

for i = 1:2
    ind = res.cues == coding(i);
    % cue onset
    onsets_cue{1,i} = res.onsets(ind);
end


% Separately model missed trials if requested
% Not here, because no button press

for i = 1:length(durations_cue)
    durations_cue{i} = cue_dur * ones(size(onsets_cue{i}));
end

%% Direction

names_direction = {'up','down'};
onsets_direction = cell(size(names_direction));
durations_direction = cell(size(names_direction));


coding = [90 270]; % up = 90; down = 270;

for i = 1:2
    ind = res.directions == coding(i);
    % cue onset + cue_dur + ISI1 = stimulus onset
    onsets_direction{1,i} = res.onsets(ind) + cue_dur + ISI1;
end


% Separately model missed trials if requested
% Not here, because no button press

for i = 1:length(durations_direction)
    durations_direction{i} = stim_dur * ones(size(onsets_direction{i}));
end

%% Color

names_color = {'red','green'};
onsets_color = cell(size(names_color));
durations_color = cell(size(names_color));


coding = [1 2]; % red = 1; green = 2;

for i = 1:2
    ind = res.colors == coding(i);
    % cue onset + cue_dur + ISI1 = stimulus onset
    onsets_color{1,i} = res.onsets(ind) + cue_dur + ISI1;
end


% Separately model missed trials if requested
% Not here, because no button press

for i = 1:length(durations_color)
    durations_color{i} = stim_dur * ones(size(onsets_color{i}));
end


%% Button presses
names_buttonpresses = {'button left','button right'};
onsets_buttonpresses = cell(size(names_buttonpresses));
durations_buttonpresses = cell(size(names_buttonpresses));


coding = [-1 1]; % button_left = -1; button_right = 1;

for i = 1:2
    ind = res.buttonpress == coding(i);
    % cue onset + cue duration + ISI1 + stimulus duration + ISI2 + response time = onset of button press
    onsets_buttonpresses{1,i} = res.onsets(ind) + cue_dur + ISI1 + stim_dur + ISI2 + res.RT(ind);
end


% Separately model missed trials if requested
% Not here, because no button press


% Event modeled as 0 duration
for i = 1:length(durations_buttonpresses)
    durations_buttonpresses{i} = zeros(size(onsets_buttonpresses{i}));
end


%% Concatenate

names = [names_cue names_direction names_color names_buttonpresses];
onsets = [onsets_cue onsets_direction onsets_color onsets_buttonpresses];
durations = [durations_cue durations_direction durations_color durations_buttonpresses];


%% End of modification

varargout{1} = names;
varargout{2} = onsets;
varargout{3} = durations;
if exist('pmod','var')
    varargout{4} = pmod;
end

if save_on
    if ~isdir(output_dir), mkdir(output_dir), end
    if exist('pmod','var')
        save(fullfile(output_dir,outputname),'names','onsets','durations','pmod')
    else
        save(fullfile(output_dir,outputname),'names','onsets','durations')
    end
end

end

warning('on',[mfilename ':overwrite'])