function varargout = getons_rule(cfg,i_sub,save_on,overwrite)

% Model rule depending on cue and dimension
% red on left (green on right) vs. red on right (green on left)
% up on left (down on right) vs. up on right (down on left)

if ~exist('save_on','var')
    save_on = 0;
end

if ~exist('overwrite','var')
    overwrite = 0;
end

onsname = mfilename;
onsname = onsname(8:end);
if isempty(onsname), onsname = 'test'; end

for i_run = cfg.sub(i_sub).run_indices

outputname = sprintf('%s_sub%02d_run%02d.mat',onsname,i_sub,i_run);

output_dir = fullfile(cfg.sub(i_sub).dir,'onsets',onsname);

if exist(fullfile(output_dir,outputname),'file')
    if overwrite
        warning([mfilename ':overwrite'],'Overwriting files in %s',output_dir);
        warning('off',[mfilename ':overwrite'])       
    else
        error('File %s already exists! Set overwrite = 1 or run different analysis.',fullfile(output_dir,outputname));
    end
end

res = convert_results; % get results matrix
res = res{i_sub,i_run}; % also converts to seconds

cue_dur = 1.5;
ISI1 = 1;
stim_dur = 6;
ISI2 = 1;
ITI = 1;
rule_dur = 1.5;

%% This is the only part of code modified for this function

[res,res_missed] = remove_missed(res);


%% Responsemapping

names = {'red left','red right','up left','up right'};
onsets = cell(size(names));
durations = cell(size(names));

for i_trial = 1:length(res.onsets)
    if res.cues(i_trial) == 1 % color
        if res.responsemapping(i_trial) <=2 % red left
           % cue onset + cue duration + ISI1 + stimulus duration + ISI2
           onsets{1,1}(1,end+1) = res.onsets(i_trial) + cue_dur + ISI1 + stim_dur + ISI2;
        else % red right
           onsets{1,2}(1,end+1) = res.onsets(i_trial); 
        end
    else % direction
        if mod(res.responsemapping(i_trial),2) % up left
           onsets{1,3}(1,end+1) = res.onsets(i_trial);
        else % up right
           onsets{1,4}(1,end+1) = res.onsets(i_trial); 
        end
    end
end

% Separately model missed trials if requested
% Not here, because no button press

for i = 1:length(durations)
    durations{i} = rule_dur * ones(size(onsets{i}));
end


%% End of modification

varargout{1} = names;
varargout{2} = onsets;
varargout{3} = durations;
if exist('pmod','var')
    varargout{4} = pmod;
end

if save_on
    if ~isdir(output_dir), mkdir(output_dir), end
    if exist('pmod','var')
        save(fullfile(output_dir,outputname),'names','onsets','durations','pmod')
    else
        save(fullfile(output_dir,outputname),'names','onsets','durations')
    end
end

end

warning('on',[mfilename ':overwrite'])